.. wger Workout Manager documentation master file, created by
   sphinx-quickstart on Mon Dec  1 22:22:02 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to wger Workout Manager's documentation!
================================================

wger is a free, open source web application that manages your exercises and
personal workouts, weight and nutrition. It can also be used as a simple gym
management utility, providing different administrative roles (trainer, manager,
etc.). It offers a REST API as well, for easy integration with other projects
and tools. It is written with python/django and uses jQuery and some D3js for charts.

For more details and a live system, refer to the project's site:
https://github.com/wger-project/wger


This documentation is intended for developers and administrators of the software.


Installation and development
----------------------------
.. toctree::
   :maxdepth: 2

   getting_started
   settings
   commands
   tips_and_tricks
   codingstyle
   i18n


Administration guide
--------------------
.. toctree::
   :maxdepth: 2

   gym


Changelog
---------
.. toctree::
   :maxdepth: 2

   changelog

Contact
-------

Feel free to contact us if you found this useful or if there was something that
didn't behave as you expected (in this case you can also open a ticket on the
issue tracker).

* **gitter:** https://gitter.im/wger-project/wger
* **issue tracker:** https://github.com/wger-project/wger/issues
* **twitter:** https://twitter.com/wger_de
* **mailing list:** https://groups.google.com/group/wger / wger@googlegroups.com,
  no registration needed


Sources
-------

All the code and the content is freely available and is hosted on github:
https://github.com/wger-project/wger


Licence
-------

The application is licenced under the Affero GNU General Public License 3 or
later (AGPL 3+).

The initial exercise and ingredient data is licensed additionally under a
Creative Commons Attribution Share-Alike 3.0 (CC-BY-SA 3.0)

The documentation is released under a CC-BY-SA either version 4 of the License,
or (at your option) any later version.

Some images where taken from Wikipedia, see the SOURCES file in their respective
folders for more details.

.. include the authors file from the root folder
.. include:: ../AUTHORS.rst

